@@ -59,8 +59,11 @@ class Engine:
     if self.optimizer== "BL":
       self.weights = bl(self, perf="False")
       
-    if self.rebalance!=None:
+    if self.rebalance!=None and self.optimizer !="BL":
       self.rebalance = make_rebalance(self.start_date, self.end_date, self.optimizer, self.portfolio, self.rebalance, self.max_vol, self.weights)
+
+    if self.rebalance!=None and self.optimizer=="BL" and self.optimizer==None:
+      self.rebalance = make_rebalance(self.start_date, self.end_date, False, self.portfolio, self.rebalance, self.max_vol, self.weights)
     
 #-------------------------------------------------------------------------------------------
 def get_returns(stocks,wts, start_date, end_date=today):
@@ -853,18 +856,10 @@ def make_rebalance(start_date, end_date, optimizer, portfolio_input, rebalance,
     output_df = pd.DataFrame(index = portfolio_input)
     
     for i in range(len(dates) - 1):
-    
 
-        if str(optimizer) == "BL":
-          portfolio = Engine(
-            start_date = dates[0],
-            end_date = dates[i+1],
-            weights = allocation,
-            portfolio = portfolio_input)
-          
-
-        else:
-          portfolio = Engine(
+        
+        
+        portfolio = Engine(
             start_date = dates[0],
             end_date = dates[i+1],
             portfolio = portfolio_input,
